diff --git a/.github/workflows/codespell.yml b/.github/workflows/codespell.yml
index 3609c21cfd..db5f92e7d6 100644
--- a/.github/workflows/codespell.yml
+++ b/.github/workflows/codespell.yml
@@ -13,7 +13,7 @@ jobs:
runs-on: ubuntu-latest
steps:
- - uses: actions/checkout@v2
+ - uses: actions/checkout@v3
- uses: codespell-project/actions-codespell@master
with:
skip: js,*.svg
diff --git a/.github/workflows/markdown_style.yml b/.github/workflows/markdown_style.yml
index 578c6e8cf5..ecc5d6403f 100644
--- a/.github/workflows/markdown_style.yml
+++ b/.github/workflows/markdown_style.yml
@@ -6,7 +6,7 @@ jobs:
markdown-style:
runs-on : ubuntu-latest
steps:
- - uses: actions/checkout@v2
+ - uses: actions/checkout@v3
- name: Setup NodeJS
uses: actions/setup-node@v2
with:
diff --git a/.github/workflows/no-bad-latin.yml b/.github/workflows/no-bad-latin.yml
index 8a67e45ae3..da5bf72ac7 100644
--- a/.github/workflows/no-bad-latin.yml
+++ b/.github/workflows/no-bad-latin.yml
@@ -31,10 +31,10 @@ jobs:
# This section collects together the steps involved in running the test
steps:
# Checkout the repository. Relies on another GH-Action.
- - uses: actions/checkout@v2
+ - uses: actions/checkout@v3
# Set up the Python version. Relies on another GH-Action.
- name: Setup Python 3.7
- uses: actions/setup-python@v1
+ uses: actions/setup-python@v3
with:
python-version: 3.7
# Install Python dependencies
diff --git a/.github/workflows/schemacode_ci.yml b/.github/workflows/schemacode_ci.yml
index 51f0334e5a..2bcb2c96d3 100644
--- a/.github/workflows/schemacode_ci.yml
+++ b/.github/workflows/schemacode_ci.yml
@@ -20,7 +20,7 @@ jobs:
outputs:
skip: ${{ steps.result_step.outputs.ci-skip }}
steps:
- - uses: actions/checkout@v2
+ - uses: actions/checkout@v3
with:
fetch-depth: 0
- id: result_step
@@ -43,10 +43,10 @@ jobs:
run:
shell: bash
steps:
- - uses: actions/checkout@v2
+ - uses: actions/checkout@v3
- name: "Set up Python"
- uses: actions/setup-python@v2
+ uses: actions/setup-python@v3
with:
python-version: ${{ matrix.python-version }}
@@ -74,10 +74,10 @@ jobs:
name: Lint schemacode
steps:
- name: Check out source repository
- uses: actions/checkout@v2
+ uses: actions/checkout@v3
- name: Set up Python environment
- uses: actions/setup-python@v2
+ uses: actions/setup-python@v3
with:
python-version: "3.7"
diff --git a/.github/workflows/yml_lint.yml b/.github/workflows/yml_lint.yml
index 9f5609afa6..99e534c78b 100644
--- a/.github/workflows/yml_lint.yml
+++ b/.github/workflows/yml_lint.yml
@@ -6,9 +6,9 @@ jobs:
yml-lint:
runs-on: ubuntu-latest
steps:
- - uses: actions/checkout@v2
+ - uses: actions/checkout@v3
- name: Set up Python
- uses: actions/setup-python@v1
+ uses: actions/setup-python@v3
with:
python-version: 3.9
- name: Install dependencies
diff --git a/CONTRIBUTING.md b/CONTRIBUTING.md
index 807f7f345a..a8f740e19b 100644
--- a/CONTRIBUTING.md
+++ b/CONTRIBUTING.md
@@ -415,7 +415,7 @@ specification, do not hesitate to make a suggestion by showing a draft in a GitH
After discussion and approval by the community, you can then submit your image
in a pull request.
-Images should be added to an `images` folder that is at the same level as the Markdown file
+Images should be added to an `images` directory that is at the same level as the Markdown file
where your image will be added. For example if you want to add a figure `figure01.png` to
`src/05-derivatives/01-introduction.md` then your image should go to
`src/05-derivatives/images/figure01.png`.
@@ -629,7 +629,7 @@ reviewer as a co-author.
## Making a change to the BIDS-schema
Several aspects of the specification are defined in a set of YAML files in the
-`src/schema` folder. The content of those files is described in a dedicated
+`src/schema` directory. The content of those files is described in a dedicated
[README file](./src/schema/README.md).
### 1. Ensure that changes to the specification are matched in the schema
diff --git a/macros_doc.md b/macros_doc.md
index b130b961cd..c202891717 100644
--- a/macros_doc.md
+++ b/macros_doc.md
@@ -17,7 +17,7 @@ in the BIDS specification.
- [Do I need learn how to program to use those macros?](#do-i-need-learn-how-to-program-to-use-those-macros)
- [Anything else I need to know if I need to insert a new macro call?](#anything-else-i-need-to-know-if-i-need-to-insert-a-new-macro-call)
- [How-To and Examples](#how-to-and-examples)
- - [Writing folder content examples](#writing-folder-content-examples)
+ - [Writing directory content examples](#writing-directory-content-examples)
- [Generating tables](#generating-tables)
- [Modifying a term in the table](#modifying-a-term-in-the-table)
- [Why would you NOT want to modify the content of the yml file directly ?](#why-would-you-not-want-to-modify-the-content-of-the-yml-file-directly-)
@@ -113,7 +113,7 @@ correct terms in the schema. This process is illustrated in the next section.
Note that under the hood the macros themselves call python code that can be
found in the
-[`tools` folder](https://github.com/bids-standard/bids-specification/tree/master/tools).
+[`tools` directory](https://github.com/bids-standard/bids-specification/tree/master/tools).
If you are interested in creating a new macro for users, this would be useful.
## Anything else I need to know if I need to insert a new macro call?
@@ -146,7 +146,7 @@ and a guide for editing at .
## How-To and Examples
-### Writing folder content examples
+### Writing directory content examples
One of the simplest macro we use helps us create consistent "file tree" examples
that would look like this in the final document:
@@ -173,7 +173,7 @@ To do this get this output, your macro call would look like this:
) }}
```
-When you have complex files and folder structure, we suggest you use this
+When you have complex files and directory structure, we suggest you use this
[Jupyter notebook](tools/filetree_example.ipynb) for sandboxing your example
before you insert the macro call into the markdown document.
diff --git a/src/01-introduction.md b/src/01-introduction.md
index 507a1fd74c..f3342ba00a 100644
--- a/src/01-introduction.md
+++ b/src/01-introduction.md
@@ -40,7 +40,7 @@ and the INCF Neuroimaging Data Sharing (NIDASH) Task Force.
While working on BIDS we consulted
many neuroscientists to make sure it covers most common experiments, but at the
same time is intuitive and easy to adopt. The specification is intentionally
-based on simple file formats and folder structures to reflect current lab
+based on simple file formats and directory structures to reflect current lab
practices and make it accessible to a wide range of scientists coming from
different backgrounds.
diff --git a/src/02-common-principles.md b/src/02-common-principles.md
index ec2c4aba5a..ca238fa64c 100644
--- a/src/02-common-principles.md
+++ b/src/02-common-principles.md
@@ -140,7 +140,7 @@ T2 volume does not need to be included, but when it is available it should be
saved under a particular filename specified in the standard. This standard
aspires to describe a majority of datasets, but acknowledges that there will be
cases that do not fit. In such cases one can include additional files and
-subfolders to the existing folder structure following common sense. For example
+subdirectories to the existing directory structure following common sense. For example
one may want to include eye tracking data in a vendor specific format that is
not covered by this standard. The most sensible place to put it is next to the
continuous recording file with the same naming scheme but different extensions.
@@ -156,7 +156,7 @@ Two prominent examples of entities are `subject` and `session`.
For a data file that was collected in a given `session` from a given
`subject`, the filename MUST begin with the string `sub-_ses-`.
-If the `session` level is omitted in the folder structure, the filename MUST begin
+If the `session` level is omitted in the directory structure, the filename MUST begin
with the string `sub-`, without `ses-`.
Note that `sub-` corresponds to the `subject` entity because it has
@@ -165,10 +165,10 @@ correspond to a unique identifier of that subject, such as `01`.
The same holds for the `session` entity with its `ses-` key and its ``
value.
-The extra session layer (at least one `/ses-` subfolder) SHOULD
+The extra session layer (at least one `/ses-` subdirectory) SHOULD
be added for all subjects if at least one subject in the dataset has more than
one session.
-If a `/ses-` subfolder is included as part of the directory hierarchy,
+If a `/ses-` subdirectory is included as part of the directory hierarchy,
then the same [`ses-`](./99-appendices/09-entities.md#ses)
key/value pair MUST also be included as part of the filenames themselves.
Acquisition time of session can
@@ -252,16 +252,16 @@ recommending a particular naming scheme for including different types of
source data (such as the raw event logs or parameter files, before conversion to BIDS).
However, in the case that these data are to be included:
-1. These data MUST be kept in separate `sourcedata` folder with a similar
- folder structure as presented below for the BIDS-managed data. For example:
+1. These data MUST be kept in separate `sourcedata` directory with a similar
+ directory structure as presented below for the BIDS-managed data. For example:
`sourcedata/sub-01/ses-pre/func/sub-01_ses-pre_task-rest_bold.dicom.tgz` or
`sourcedata/sub-01/ses-pre/func/MyEvent.sce`.
-1. A README file SHOULD be found at the root of the `sourcedata` folder or the
- `derivatives` folder, or both.
+1. A README file SHOULD be found at the root of the `sourcedata` directory or the
+ `derivatives` directory, or both.
This file should describe the nature of the raw data or the derived data.
We RECOMMEND including the PDF print-out with the actual sequence
- parameters generated by the scanner in the `sourcedata` folder.
+ parameters generated by the scanner in the `sourcedata` directory.
Alternatively one can organize their data in the following way
@@ -287,17 +287,17 @@ Alternatively one can organize their data in the following way
) }}
In this example, where `sourcedata` and `derivatives` are not nested inside
-`rawdata`, **only the `rawdata` subfolder** needs to be a BIDS-compliant
+`rawdata`, **only the `rawdata` subdirectory** needs to be a BIDS-compliant
dataset.
-The subfolders of `derivatives` MAY be BIDS-compliant derivatives datasets
+The subdirectories of `derivatives` MAY be BIDS-compliant derivatives datasets
(see [Non-compliant derivatives](#non-compliant-derivatives) for further discussion).
This specification does not prescribe anything about the contents of `sourcedata`
-folders in the above example - nor does it prescribe the `sourcedata`,
-`derivatives`, or `rawdata` folder names.
+directories in the above example - nor does it prescribe the `sourcedata`,
+`derivatives`, or `rawdata` directory names.
The above example is just a convention that can be useful for organizing raw,
source, and derived data while maintaining BIDS compliance of the raw data
-folder. When using this convention it is RECOMMENDED to set the `SourceDatasets`
-field in `dataset_description.json` of each subfolder of `derivatives` to:
+directory. When using this convention it is RECOMMENDED to set the `SourceDatasets`
+field in `dataset_description.json` of each subdirectory of `derivatives` to:
```JSON
{
@@ -309,18 +309,18 @@ field in `dataset_description.json` of each subfolder of `derivatives` to:
Derivatives can be stored/distributed in two ways:
-1. Under a `derivatives/` subfolder in the root of the source BIDS dataset
- folder to make a clear distinction between raw data and results of data
+1. Under a `derivatives/` subdirectory in the root of the source BIDS dataset
+ directory to make a clear distinction between raw data and results of data
processing.
A data processing pipeline will typically have a dedicated directory
under which it stores all of its outputs.
Different components of a pipeline can, however, also be stored under different
- subfolders.
+ subdirectories.
There are few restrictions on the directory names;
it is RECOMMENDED to use the format `-` in cases where
it is anticipated that the same pipeline will output more than one variant
(for example, `AFNI-blurring` and `AFNI-noblurring`).
- For the sake of consistency, the subfolder name SHOULD be
+ For the sake of consistency, the subdirectory name SHOULD be
the `GeneratedBy.Name` field in `data_description.json`,
optionally followed by a hyphen and a suffix (see
[Derived dataset and pipeline description][derived-dataset-description]).
@@ -397,7 +397,7 @@ session subdirectory within the corresponding subject directory; and so on.
Nothing in this specification should be interpreted to disallow the
storage/distribution of non-compliant derivatives of BIDS datasets.
-In particular, if a BIDS dataset contains a `derivatives/` sub-directory,
+In particular, if a BIDS dataset contains a `derivatives/` subdirectory,
the contents of that directory may be a heterogeneous mix of BIDS Derivatives
datasets and non-compliant derivatives.
@@ -819,7 +819,7 @@ Describing dates and timestamps:
### Single session example
-This is an example of the folder and file structure. Because there is only one
+This is an example of the directory and file structure. Because there is only one
session, the session level is not required by the format. For details on
individual files see descriptions in the next section:
@@ -864,7 +864,7 @@ individual files see descriptions in the next section:
## Unspecified data
-Additional files and folders containing raw data MAY be added as needed for
+Additional files and directories containing raw data MAY be added as needed for
special cases.
All non-standard file entities SHOULD conform to BIDS-style naming conventions, including
alphabetic entities and suffixes and alphanumeric labels/indices.
diff --git a/src/03-modality-agnostic-files.md b/src/03-modality-agnostic-files.md
index 822bb197c7..f46cca8615 100644
--- a/src/03-modality-agnostic-files.md
+++ b/src/03-modality-agnostic-files.md
@@ -105,8 +105,8 @@ In contrast to raw BIDS datasets, derived BIDS datasets MUST include a
}
) }}
-If a derived dataset is stored as a subfolder of the raw dataset, then the `Name` field
-of the first `GeneratedBy` object MUST be a substring of the derived dataset folder name.
+If a derived dataset is stored as a subdirectory of the raw dataset, then the `Name` field
+of the first `GeneratedBy` object MUST be a substring of the derived dataset directory name.
That is, in a directory `/derivatives/[-]/`, the first
`GeneratedBy` object should have a `Name` of ``.
diff --git a/src/04-modality-specific-files/01-magnetic-resonance-imaging-data.md b/src/04-modality-specific-files/01-magnetic-resonance-imaging-data.md
index 41969de679..4c3d47dd13 100644
--- a/src/04-modality-specific-files/01-magnetic-resonance-imaging-data.md
+++ b/src/04-modality-specific-files/01-magnetic-resonance-imaging-data.md
@@ -161,7 +161,7 @@ diffusion and functional MRI may also be *intended for* estimating the
*B0 * field nonuniformity inside the scanner (in other words,
*mapping the field*) without the acquisition of additional MRI schemes
such as gradient-recalled echo (GRE) sequences that are stored under the
-`fmap/` folder of the BIDS structure.
+`fmap/` directory of the BIDS structure.
The modality labels `dwi` (under `dwi/`), `bold` (under `func/`),
`asl` (under `perf/`), `sbref` (under `dwi/`, `func/` or `perf/`), and
diff --git a/src/04-modality-specific-files/02-magnetoencephalography.md b/src/04-modality-specific-files/02-magnetoencephalography.md
index 7ba79f7c45..e1d03756a5 100644
--- a/src/04-modality-specific-files/02-magnetoencephalography.md
+++ b/src/04-modality-specific-files/02-magnetoencephalography.md
@@ -44,8 +44,8 @@ If multiple *Tasks* were performed within a single *Run*,
the task description can be set to `task-multitask`.
The `*_meg.json` file SHOULD contain details on the *Tasks*.
-Some manufacturers' data storage conventions use folders which contain data
-files of various nature: for example, CTF's `.ds` format, or BTi/4D's data folder.
+Some manufacturers' data storage conventions use directories which contain data
+files of various nature: for example, CTF's `.ds` format, or BTi/4D's data directory.
Yet other manufacturers split their files once they exceed a certain size
limit.
For example Neuromag/Elekta/Megin, which can produce several files
@@ -475,7 +475,7 @@ Empty-room MEG recordings capture the environmental and recording system's
noise.
In the context of BIDS it is RECOMMENDED to perform an empty-room recording for
each experimental session.
-It is RECOMMENDED to store the empty-room recording inside a subject folder
+It is RECOMMENDED to store the empty-room recording inside a subject directory
named `sub-emptyroom`.
The label for the [`task-`](../99-appendices/09-entities.md#task) entity in the empty-room recording SHOULD be
set to `noise`.
diff --git a/src/04-modality-specific-files/04-intracranial-electroencephalography.md b/src/04-modality-specific-files/04-intracranial-electroencephalography.md
index e4d1b0cbf8..85ca8fbc78 100644
--- a/src/04-modality-specific-files/04-intracranial-electroencephalography.md
+++ b/src/04-modality-specific-files/04-intracranial-electroencephalography.md
@@ -525,7 +525,7 @@ other task events. Electrical stimulation parameters can be described in columns
called `electrical_stimulation_`, with labels chosen by the researcher and
optionally defined in more detail in an accompanying `_events.json` file (as
per the main BIDS spec). Functions for complex stimulation patterns can, similar
-as when a video is presented, be stored in a folder in the `/stimuli/` folder.
+as when a video is presented, be stored in a directory in the `/stimuli/` directory.
For example: `/stimuli/electrical_stimulation_functions/biphasic.tsv`
Example:
diff --git a/src/04-modality-specific-files/05-task-events.md b/src/04-modality-specific-files/05-task-events.md
index 5188a8c1ae..cdda5e2e3b 100644
--- a/src/04-modality-specific-files/05-task-events.md
+++ b/src/04-modality-specific-files/05-task-events.md
@@ -127,17 +127,17 @@ for additional information and examples.
Additional information about the stimuli can be added in the `events.tsv`
and `events.json` files.
-This can be done by using a `/stimuli` folder or by reference to a stimuli database.
+This can be done by using a `/stimuli` directory or by reference to a stimuli database.
-### Stimuli folder
+### Stimuli directory
-The stimulus files can be added in a `/stimuli` folder
-(under the root folder of the dataset; with optional subfolders) AND using a
+The stimulus files can be added in a `/stimuli` directory
+(under the root directory of the dataset; with optional subdirectories) AND using a
`stim_file` column in `events.tsv` mentioning which stimulus file was used
for a given event,
There are no restrictions on the file formats of the stimuli files,
-but they should be stored in the `/stimuli` folder.
+but they should be stored in the `/stimuli` directory.
{{ MACROS___make_columns_table(
{
diff --git a/src/04-modality-specific-files/07-behavioral-experiments.md b/src/04-modality-specific-files/07-behavioral-experiments.md
index 0406871b15..23747807d1 100644
--- a/src/04-modality-specific-files/07-behavioral-experiments.md
+++ b/src/04-modality-specific-files/07-behavioral-experiments.md
@@ -5,7 +5,7 @@
In addition to logs from behavioral experiments performed alongside imaging data
acquisitions, one can also include data from experiments performed with no neural
recordings.
-The results of those experiments can be stored in the `beh` folder using the same
+The results of those experiments can be stored in the `beh` directory using the same
formats for event timing (`_events.tsv`), metadata (`_events.json`),
physiological (`_physio.tsv.gz`, `_physio.json`)
and other continuous recordings (`_stim.tsv.gz`, `_stim.json`)
@@ -31,10 +31,10 @@ In addition to the metadata that is either:
- RECOMMENDED for sidecar JSON files for [tabular data](../02-common-principles.md#tabular-data), or
-- REQUIRED for some data that can be found in the `beh` folder
+- REQUIRED for some data that can be found in the `beh` directory
(for example `SamplingFrequency` and `StartTime` for `*_.tsv.gz` files),
-it is RECOMMENDED to add the following metadata to the JSON files of this folder:
+it is RECOMMENDED to add the following metadata to the JSON files of this directory:
{{ MACROS___make_metadata_table(
{
diff --git a/src/04-modality-specific-files/10-microscopy.md b/src/04-modality-specific-files/10-microscopy.md
index 4c03988744..cb9f486081 100644
--- a/src/04-modality-specific-files/10-microscopy.md
+++ b/src/04-modality-specific-files/10-microscopy.md
@@ -208,7 +208,7 @@ JSON metadata may be defined per sample or per chunk as appropriate, as per the
In microscopy, many pyramidal file formats store multiple resolutions for the same acquisition.
In the case where a multiple resolutions file format is converted to single resolution file format,
only the higher resolution file is present in the raw data.
-Lower resolutions files MUST be placed under the `derivatives` folder and use the
+Lower resolutions files MUST be placed under the `derivatives` directory and use the
[`res-`](../99-appendices/09-entities.md#res) entity.
For example:
diff --git a/src/99-appendices/06-meg-file-formats.md b/src/99-appendices/06-meg-file-formats.md
index 7036eb32a0..b00cee525a 100644
--- a/src/99-appendices/06-meg-file-formats.md
+++ b/src/99-appendices/06-meg-file-formats.md
@@ -5,9 +5,9 @@ RECOMMENDED values for `manufacturer_specific_extensions`:
| **Value** | **Description** |
| --------------------------------------------------- | ------------------------------------------------------------------------------------- |
-| [`ctf`](06-meg-file-formats.md#ctf) | CTF (folder with `.ds` extension) |
+| [`ctf`](06-meg-file-formats.md#ctf) | CTF (directory with `.ds` extension) |
| [`fif`](06-meg-file-formats.md#neuromagelektamegin) | Neuromag / Elekta / MEGIN and BabyMEG (file with extension `.fif`) |
-| [`4d`](06-meg-file-formats.md#bti4d-neuroimaging) | BTi / 4D Neuroimaging (folder containing multiple files without extensions) |
+| [`4d`](06-meg-file-formats.md#bti4d-neuroimaging) | BTi / 4D Neuroimaging (directory containing multiple files without extensions) |
| [`kit`](06-meg-file-formats.md#kityokogawaricoh) | KIT / Yokogawa / Ricoh (file with extension `.sqd`, `.con`, `.raw`, `.ave` or `.mrk`) |
| [`kdf`](06-meg-file-formats.md#kriss) | KRISS (file with extension `.kdf`) |
| [`itab`](06-meg-file-formats.md#itab) | Chieti system (file with extension `.raw` and `.mhd`) |
@@ -16,10 +16,10 @@ Below are specifications for each system brand.
## CTF
-Each experimental run with a CTF system yields a folder with a `.ds` extension,
+Each experimental run with a CTF system yields a directory with a `.ds` extension,
containing several files. The OPTIONAL digitized positions of the head points
are usually stored in a separate `.pos` file, not necessarily within the `.ds`
-folder.
+directory.
```Text
[sub-[_ses-]_headshape.pos]
@@ -90,10 +90,10 @@ entity.
Note that cross-talk files MUST be denoted using `acq-crosstalk` and
fine-calibration files MUST be denoted using `acq-calibration`.
-The cross-talk and fine-calibration data MUST be stored in the subject-level `meg` folder,
-which may be nested inside a `ses-` folder, as shown in the following examples.
+The cross-talk and fine-calibration data MUST be stored in the subject-level `meg` directory,
+which may be nested inside a `ses-` directory, as shown in the following examples.
-#### Example with single session (omitted session folder)
+#### Example with single session (omitted session directory)
{{ MACROS___make_filetree_example(
{
@@ -155,7 +155,7 @@ which may be nested inside a `ses-` folder, as shown in the following exa
After applying SSS (for example, by using the MaxFilter software),
files SHOULD be renamed with the corresponding label (for example, `proc-sss`)
-and placed in a `derivatives` subfolder.
+and placed in a `derivatives` subdirectory.
Example:
@@ -230,7 +230,7 @@ support recording dates earlier than `1901-12-13T08:45:53.000000` UTC or later t
## BTi/4D neuroimaging
-Each experimental run on a 4D neuroimaging/BTi system results in a folder
+Each experimental run on a 4D neuroimaging/BTi system results in a directory
containing multiple files without extensions.
```Text
@@ -329,7 +329,7 @@ More about the KIT/Yokogawa/Ricoh data organization at:
## KRISS
Each experimental run on the KRISS system produces a file with extension
-`.kdf`. Additional files can be available in the same folder: the digitized
+`.kdf`. Additional files can be available in the same directory: the digitized
positions of the head points (`\_digitizer.txt`), the position of the center of
the MEG coils (`.chn`) and the event markers (`.trg`).
diff --git a/src/99-appendices/11-qmri.md b/src/99-appendices/11-qmri.md
index 6c4a349907..b58f410df7 100644
--- a/src/99-appendices/11-qmri.md
+++ b/src/99-appendices/11-qmri.md
@@ -40,7 +40,7 @@ application by creating logical groups of input files through `suffix` and certa
representing acquisition parameters (`echo`, `flip`, `inv`, `mt`) or file parts (`part`).
If a qMRI file collection is intended for creating structural quantitative maps (for example, `T1map`),
-files belonging to that collection are stored in the `anat` subfolder.
+files belonging to that collection are stored in the `anat` subdirectory.
Below is an example file collection for `MP2RAGE`:
{{ MACROS___make_filetree_example(
@@ -60,7 +60,7 @@ Below is an example file collection for `MP2RAGE`:
Commonly, RF fieldmaps (`B1+` and `B1-` maps) are used for the correction of structural quantitative maps.
As these images do not convey substantial structural information,
-respective file collections of RF fieldmaps are stored in the `fmap` subfolder.
+respective file collections of RF fieldmaps are stored in the `fmap` subdirectory.
Below is an example file collection for RF transmit field map `TB1EPI`:
{{ MACROS___make_filetree_example(
@@ -84,7 +84,7 @@ Please visit the [file collections appendix](./10-file-collections.md#magnetic-r
### Quantitative maps are derivatives
-Regardless of how they are obtained (pre- or post-generated), qMRI maps are stored in the `derivatives` folder.
+Regardless of how they are obtained (pre- or post-generated), qMRI maps are stored in the `derivatives` directory.
For example a `T1map` can be generated from an `MP2RAGE` file collection using either options.
If the map is post-generated:
@@ -194,7 +194,7 @@ Explanation of the table:
As qMRI maps are stored as derivatives, they are subjected to the metadata requirements of
[derived datasets](../03-modality-agnostic-files.md#derived-dataset-and-pipeline-description).
-An example `dataset_description.json` for a qMRI map derivatives folder:
+An example `dataset_description.json` for a qMRI map derivatives directory:
{{ MACROS___make_filetree_example(
{
@@ -416,7 +416,7 @@ raw dataset directory along with the `MP2RAGE` file collection and to be used as
for quantifying a `T1map`.
If an additional `UNIT1` image is calculated offline, then the output is to be stored in the
-`derivatives` folder with necessary provenance information.
+`derivatives` directory with necessary provenance information.
##### `NumberShots` metadata field
diff --git a/src/CHANGES.md b/src/CHANGES.md
index 2988478002..bffffb8630 100644
--- a/src/CHANGES.md
+++ b/src/CHANGES.md
@@ -130,7 +130,7 @@
- \[FIX] Mix up (typo) between ficiduals and landmarks in EEG spec [#754](https://github.com/bids-standard/bids-specification/pull/754) ([rob-luke](https://github.com/rob-luke))
- \[INFRA] updating remark, CIs, contributor docs [#745](https://github.com/bids-standard/bids-specification/pull/745) ([sappelhoff](https://github.com/sappelhoff))
- \[FIX] schema for i/eeg coordsys+elecs: sub-ses-acq-space are allowed entities [#743](https://github.com/bids-standard/bids-specification/pull/743) ([sappelhoff](https://github.com/sappelhoff))
-- \[DOC] move schema documentation into the schema folder [#740](https://github.com/bids-standard/bids-specification/pull/740) ([Remi-Gau](https://github.com/Remi-Gau))
+- \[DOC] move schema documentation into the schema directory [#740](https://github.com/bids-standard/bids-specification/pull/740) ([Remi-Gau](https://github.com/Remi-Gau))
- \[MISC] standardize string examples format in tables [#739](https://github.com/bids-standard/bids-specification/pull/739) ([Remi-Gau](https://github.com/Remi-Gau))
- \[MISC] Clarify participant_id in participants.tsv file if it exists [#738](https://github.com/bids-standard/bids-specification/pull/738) ([adam2392](https://github.com/adam2392))
- \[FIX] split MEG files should be listed separately in scans.tsv [#735](https://github.com/bids-standard/bids-specification/pull/735) ([eort](https://github.com/eort))
@@ -302,7 +302,7 @@
- \[FIX] Clarify channels.tsv is RECOMMENDED consistently across ephys [#347](https://github.com/bids-standard/bids-specification/pull/347) ([sappelhoff](https://github.com/sappelhoff))
- \[FIX] Typo fix (contract -> contrast) in events documentation [#346](https://github.com/bids-standard/bids-specification/pull/346) ([snastase](https://github.com/snastase))
- \[MISC] rm TOC.md - seems no longer pertinent/used [#341](https://github.com/bids-standard/bids-specification/pull/341) ([yarikoptic](https://github.com/yarikoptic))
-- \[MISC] Move the PR template to a separate folder and improve contents [#338](https://github.com/bids-standard/bids-specification/pull/338) ([jhlegarreta](https://github.com/jhlegarreta))
+- \[MISC] Move the PR template to a separate directory and improve contents [#338](https://github.com/bids-standard/bids-specification/pull/338) ([jhlegarreta](https://github.com/jhlegarreta))
- \[INFRA] Find npm requirements file in Circle [#336](https://github.com/bids-standard/bids-specification/pull/336) ([franklin-feingold](https://github.com/franklin-feingold))
- \[ENH] Clarify phenotypic and assessment data in new section [#331](https://github.com/bids-standard/bids-specification/pull/331) ([sappelhoff](https://github.com/sappelhoff))
- \[MISC] add information about continuous integration checks to PR template [#330](https://github.com/bids-standard/bids-specification/pull/330) ([sappelhoff](https://github.com/sappelhoff))
@@ -366,7 +366,7 @@
- \[FIX] make MEG section headings and ToC consistent to the EEG and iEEG specs [#181](https://github.com/bids-standard/bids-specification/pull/181) ([robertoostenveld](https://github.com/robertoostenveld))
- \[FIX] make section headings and ToC consistent between meg and eeg specs [#180](https://github.com/bids-standard/bids-specification/pull/180) ([robertoostenveld](https://github.com/robertoostenveld))
- \[MISC] Spelling fixes [#179](https://github.com/bids-standard/bids-specification/pull/179) ([DimitriPapadopoulos](https://github.com/DimitriPapadopoulos))
-- \[ENH] Alternative folder organization for raw, derived, and source data [#178](https://github.com/bids-standard/bids-specification/pull/178) ([chrisgorgo](https://github.com/chrisgorgo))
+- \[ENH] Alternative directory organization for raw, derived, and source data [#178](https://github.com/bids-standard/bids-specification/pull/178) ([chrisgorgo](https://github.com/chrisgorgo))
- \[INFRA] Adding instructions for naming PRs [#177](https://github.com/bids-standard/bids-specification/pull/177) ([chrisgorgo](https://github.com/chrisgorgo))
- \[MISC] Introducing Stefan Appelhoff as the first Maintainer [#176](https://github.com/bids-standard/bids-specification/pull/176) ([chrisgorgo](https://github.com/chrisgorgo))
- \[FIX] Clarify name of "BrainVision" format [#175](https://github.com/bids-standard/bids-specification/pull/175) ([JegouA](https://github.com/JegouA))
@@ -440,7 +440,7 @@
- \[MISC] corrected link that is shown for CC0 [#31](https://github.com/bids-standard/bids-specification/pull/31) ([robertoostenveld](https://github.com/robertoostenveld))
- \[INFRA] added linter integration via travis [#30](https://github.com/bids-standard/bids-specification/pull/30) ([chrisgorgo](https://github.com/chrisgorgo))
- \[MISC] Cleanup [#29](https://github.com/bids-standard/bids-specification/pull/29) ([chrisgorgo](https://github.com/chrisgorgo))
-- \[MISC] split intro, commons, mr, and meg into folder from specification.md [#28](https://github.com/bids-standard/bids-specification/pull/28) ([teonbrooks](https://github.com/teonbrooks))
+- \[MISC] split intro, commons, mr, and meg into directory from specification.md [#28](https://github.com/bids-standard/bids-specification/pull/28) ([teonbrooks](https://github.com/teonbrooks))
- \[MISC] Add some bids starter kit contributors [#27](https://github.com/bids-standard/bids-specification/pull/27) ([KirstieJane](https://github.com/KirstieJane))
- \[MISC] Embedded footnotes into text [#25](https://github.com/bids-standard/bids-specification/pull/25) ([franklin-feingold](https://github.com/franklin-feingold))
- \[MISC] Making HED Strategy Guide link prettier [#24](https://github.com/bids-standard/bids-specification/pull/24) ([fake-filo](https://github.com/fake-filo))
diff --git a/src/schema/README.md b/src/schema/README.md
index c3d142cba6..04bdca0a7c 100644
--- a/src/schema/README.md
+++ b/src/schema/README.md
@@ -32,14 +32,14 @@ The types of objects currently supported in the schema are:
- suffixes,
- metadata,
- top-level files,
-- and non-BIDS associated folders.
+- and non-BIDS associated directories.
-Each of these object types has a single file in the `objects/` folder.
+Each of these object types has a single file in the `objects/` directory.
- `modalities.yaml`: The modalities, or types of technology, used to acquire data in a BIDS dataset.
These modalities are not reflected directly in the specification.
For example, while both fMRI and DWI data are acquired with an MRI,
- in a BIDS dataset they are stored in different folders reflecting the two different `datatypes`.
+ in a BIDS dataset they are stored in different directories reflecting the two different `datatypes`.
- `datatypes.yaml`: Data types supported by the specification.
The only information provided in the file is:
@@ -48,7 +48,7 @@ Each of these object types has a single file in the `objects/` folder.
1. each datatype's full name
1. a free text description of the datatype.
-- `entities.yaml`: Entities (key/value pairs in folder and filenames).
+- `entities.yaml`: Entities (key/value pairs in directory and filenames).
- `metadata.yaml`: All valid metadata fields that are explicitly supported in BIDS sidecar JSON files.
@@ -58,7 +58,7 @@ Each of these object types has a single file in the `objects/` folder.
- `top_level_files.yaml`: Valid top-level files which may appear in a BIDS dataset.
-- `associated_data.yaml`: Folders that may appear within a dataset folder without following BIDS rules.
+- `associated_data.yaml`: Directories that may appear within a dataset directory without following BIDS rules.
### On re-used objects with different definitions
@@ -115,7 +115,7 @@ The `description` field is a freeform description of the modality.
### `datatypes.yaml`
This file contains a dictionary in which each datatype is defined.
-Keys are the folder names associated with each datatype (for example, `anat` for anatomical MRI),
+Keys are the directory names associated with each datatype (for example, `anat` for anatomical MRI),
and each associated value is a dictionary with two keys: `name` and `description`.
The `name` field is the full name of the datatype.
@@ -218,7 +218,7 @@ There are additional fields which may define rules that apply to a given type.
- `dataset_relative` (relative paths from dataset root),
- - `participant_relative` (relative paths from participant folder).
+ - `participant_relative` (relative paths from participant directory).
- `enum` defines a list of valid values for the field.
The minimum string length (`minLength`) defaults to 1.
@@ -388,21 +388,21 @@ The `description` field is a freeform description of the file.
### `associated_data.yaml`
-This file contains a dictionary in which each non-BIDS folder is defined.
-Keys are folder names, and each associated value is a dictionary with two keys: `name` and `description`.
+This file contains a dictionary in which each non-BIDS directory is defined.
+Keys are directory names, and each associated value is a dictionary with two keys: `name` and `description`.
-The `name` field is the full name of the folder.
-The `description` field is a freeform description of the folder.
+The `name` field is the full name of the directory.
+The `description` field is a freeform description of the directory.
## Rule files
-The files in the `rules/` folder are less standardized than the files in `objects/`,
+The files in the `rules/` directory are less standardized than the files in `objects/`,
because rules governing how different object types interact in a valid dataset are more variable
than the object definitions.
- `modalities.yaml`: This file simply groups `datatypes` under their associated modality.
-- `datatypes/*.yaml`: Files in the `datatypes` folder contain information about valid filenames within a given datatype.
+- `datatypes/*.yaml`: Files in the `datatypes` directory contain information about valid filenames within a given datatype.
Specifically, each datatype's YAML file contains a list of dictionaries.
Each dictionary contains a list of suffixes, entities, and file extensions which may constitute a valid BIDS filename.
@@ -410,7 +410,7 @@ than the object definitions.
- `top_level_files.yaml`: Requirement levels and valid file extensions of top-level files.
-- `associated_data.yaml`: Requirement levels of associated non-BIDS folders.
+- `associated_data.yaml`: Requirement levels of associated non-BIDS directories.
### `modalities.yaml`
@@ -419,7 +419,7 @@ The `datatypes` dictionary contains a list of datatypes that fall under that mod
### `datatypes/*.yaml`
-The files in this folder are currently the least standardized of any part of the schema.
+The files in this directory are currently the least standardized of any part of the schema.
Each file corresponds to a single `datatype`.
Within the file is a list of dictionaries.
@@ -496,5 +496,5 @@ In cases where there is a data file and a metadata file, the `.json` extension f
### `associated_data.yaml`
-This file contains a dictionary in which each key is a folder and the value is a dictionary with one key: `required`.
-The `required` entry contains a boolean value to indicate if that folder is required for BIDS datasets or not.
+This file contains a dictionary in which each key is a directory and the value is a dictionary with one key: `required`.
+The `required` entry contains a boolean value to indicate if that directory is required for BIDS datasets or not.
diff --git a/src/schema/objects/associated_data.yaml b/src/schema/objects/associated_data.yaml
index 901e17bdac..1541da72e7 100644
--- a/src/schema/objects/associated_data.yaml
+++ b/src/schema/objects/associated_data.yaml
@@ -1,12 +1,12 @@
---
-# This file describes folders that may appear within a dataset folder
+# This file describes directories that may appear within a dataset directory
# without following BIDS rules.
-# Information about whether these folders are required or not is present in
+# Information about whether these directories are required or not is present in
# `rules/associated_data.yaml`.
code:
name: Code
description: |
- A folder in which to store any code used to generate the derivatives from the
+ A directory in which to store any code used to generate the derivatives from the
source data.
derivatives:
name: Derivative data
@@ -20,10 +20,10 @@ sourcedata:
stimuli:
name: Stimulus files
description: |
- The stimulus files can be added in a `/stimuli` folder
- (under the root folder of the dataset; with optional subfolders)
+ The stimulus files can be added in a `/stimuli` directory
+ (under the root directory of the dataset; with optional subdirectories)
AND using a stim_file column in *_events.tsv mentioning which stimulus file was
used for a given event.
There are no restrictions on the file formats of the stimuli files, but they should be
- stored in the `/stimuli` folder.
+ stored in the `/stimuli` directory.
diff --git a/src/schema/objects/columns.yaml b/src/schema/objects/columns.yaml
index 1c34c936bd..36e93fe308 100644
--- a/src/schema/objects/columns.yaml
+++ b/src/schema/objects/columns.yaml
@@ -423,8 +423,8 @@ stim_file:
Represents the location of the stimulus file (such as an image, video, or
audio file) presented at the given onset time.
There are no restrictions on the file formats of the stimuli files,
- but they should be stored in the `/stimuli` folder
- (under the root folder of the dataset; with optional subfolders).
+ but they should be stored in the `/stimuli` directory
+ (under the root directory of the dataset; with optional subdirectories).
The values under the `stim_file` column correspond to a path relative to
`/stimuli`.
For example `images/cat03.jpg` will be translated to `/stimuli/images/cat03.jpg`.
diff --git a/src/schema/objects/formats.yaml b/src/schema/objects/formats.yaml
index 67a78be33f..4abc02fa84 100644
--- a/src/schema/objects/formats.yaml
+++ b/src/schema/objects/formats.yaml
@@ -46,9 +46,9 @@ bids_uri:
starting with "bids:".
pattern: 'bids:[0-9a-zA-Z/#:\?\_\-\.]+'
dataset_relative:
- name: Path relative to the BIDS dataset folder
+ name: Path relative to the BIDS dataset directory
description: |
- A path to a file, relative to the dataset folder.
+ A path to a file, relative to the dataset directory.
The validation for this format is minimal.
It simply ensures that the value is a string with any characters that may appear in a valid path,
@@ -77,14 +77,14 @@ file_relative:
without starting with "/" (an absolute path).
pattern: '(?!/)[0-9a-zA-Z/\_\-\.]+'
participant_relative:
- name: Path relative to the participant folder
+ name: Path relative to the participant directory
description: |
- A path to a file, relative to the participant's folder in the dataset.
+ A path to a file, relative to the participant's directory in the dataset.
The validation for this format is minimal.
It simply ensures that the value is a string with any characters that may appear in a valid path,
without starting with "/" (an absolute path) or "sub/"
- (a relative path starting with the participant folder, rather than relative to that folder).
+ (a relative path starting with the participant directory, rather than relative to that directory).
pattern: '(?!/)(?!sub-)[0-9a-zA-Z/\_\-\.]+'
rrid:
name: Research resource identifier
@@ -92,14 +92,14 @@ rrid:
A [research resource identifier](https://scicrunch.org/resources).
pattern: 'RRID:.+_.+'
stimuli_relative:
- name: Path relative to the stimuli folder
+ name: Path relative to the stimuli directory
description: |
- A path to a stimulus file, relative to a `/stimuli` folder somewhere.
+ A path to a stimulus file, relative to a `/stimuli` directory somewhere.
The validation for this format is minimal.
It simply ensures that the value is a string with any characters that may appear in a valid path,
without starting with "/" (an absolute path) or "stimuli/"
- (a relative path starting with the stimuli folder, rather than relative to that folder).
+ (a relative path starting with the stimuli directory, rather than relative to that directory).
pattern: '(?!/)(?!stimuli/)[0-9a-zA-Z/\_\-\.]+'
time:
name: Time
diff --git a/src/schema/objects/metadata.yaml b/src/schema/objects/metadata.yaml
index 2f182ae71c..61bf8dcc6a 100644
--- a/src/schema/objects/metadata.yaml
+++ b/src/schema/objects/metadata.yaml
@@ -134,7 +134,7 @@ ArterialSpinLabelingType:
AssociatedEmptyRoom:
name: AssociatedEmptyRoom
description: |
- Relative path in BIDS folder structure to empty-room file associated with
+ Relative path in BIDS directory structure to empty-room file associated with
the subject's MEG recording.
The path needs to use forward slashes instead of backward slashes
(for example,
@@ -1279,7 +1279,7 @@ IntendedFor:
description: |
The paths to files for which the associated file is intended to be used.
Contains one or more filenames with paths relative to the participant
- subfolder.
+ subdirectory.
Paths need to use forward slashes instead of backward slashes,
regardless of operating system.
anyOf:
diff --git a/src/schema/rules/associated_data.yaml b/src/schema/rules/associated_data.yaml
index 609fcafaa5..b855bf9a25 100644
--- a/src/schema/rules/associated_data.yaml
+++ b/src/schema/rules/associated_data.yaml
@@ -1,6 +1,6 @@
---
-# This file describes the requirement levels of folders which may appear
-# within a dataset folder without following BIDS format.
+# This file describes the requirement levels of directories which may appear
+# within a dataset directory without following BIDS format.
code:
required: false
derivatives:
diff --git a/tools/examplecode/example.py b/tools/examplecode/example.py
index 95be6c19c1..abaac4663b 100644
--- a/tools/examplecode/example.py
+++ b/tools/examplecode/example.py
@@ -45,7 +45,7 @@ def build_tree(self):
def _tree_body(self, directory, prefix=""):
"""
- Loops through the dictionary content representing a folder
+ Loops through the dictionary content representing a directory
and append the content to the tree.
This is done recursively any time a new dictionary is encountered.
"""
@@ -54,7 +54,7 @@ def _tree_body(self, directory, prefix=""):
for index, entry in enumerate(directory):
- # change connector if this is the last item in this folder
+ # change connector if this is the last item in this directory
connector = self.ELBOW if index == entries_count - 1 else self.TEE
self._add_dictionary(
directory, entry, index, entries_count, prefix, connector
diff --git a/tools/filetree_example.ipynb b/tools/filetree_example.ipynb
index 3c02f18a8f..81d7876d5e 100644
--- a/tools/filetree_example.ipynb
+++ b/tools/filetree_example.ipynb
@@ -34,7 +34,7 @@
"outputs": [],
"source": [
"directory_dict = {\n",
- " \"sub-01\": { # use nested dictionaries to represent folders\n",
+ " \"sub-01\": { # use nested dictionaries to represent directories\n",
" \"sub-01_part-mag_T1w.nii.gz\" : \"\",\n",
" \"sub-01_part-mag_T1w.json\" : \"\",\n",
" \"sub-01_part-phase_T1w.nii.gz\" : \"\",\n",
@@ -58,7 +58,7 @@
"source": [
"nested_directory_dict = {\n",
" \"sub-01\" : {\n",
- " \"anat\": { # you can represent subfolders by nesting directories\n",
+ " \"anat\": { # you can represent subdirectories by nesting directories\n",
" \"sub-01_part-mag_T1w.nii.gz\" : \"\",\n",
" \"sub-01_part-mag_T1w.json\" : \"\",\n",
" \"sub-01_part-phase_T1w.nii.gz\" : \"\",\n",
@@ -86,7 +86,7 @@
" \"...\" : \"\",\n",
" },\n",
" \"sourcedata\": {\n",
- " \"sub-01\" : {}, # use empty dictionaries to represent folders without specifying their content\n",
+ " \"sub-01\" : {}, # use empty dictionaries to represent directories without specifying their content\n",
" \"sub-02\" : {},\n",
" \"...\" : \"\",\n",
" },\n",
@@ -107,7 +107,7 @@
"metadata": {},
"outputs": [],
"source": [
- "# you can also represent files and folders on the same level\n",
+ "# you can also represent files and directories on the same level\n",
"\n",
"directory = {\n",
" \"dataset_description.json\" : \"\",\n",
diff --git a/tools/schemacode/schemacode/render.py b/tools/schemacode/schemacode/render.py
index ea4f0fd1f9..c1b8872142 100644
--- a/tools/schemacode/schemacode/render.py
+++ b/tools/schemacode/schemacode/render.py
@@ -176,7 +176,7 @@ def make_filename_template(schema, n_dupes_to_combine=6, **kwargs):
entity_order = schema["rules"]["entities"]
paragraph = ""
- # Parent folders
+ # Parent directories
paragraph += "{}-<{}>/\n\t[{}-<{}>/]\n".format(
schema["objects"]["entities"]["subject"]["entity"],
schema["objects"]["entities"]["subject"]["format"],
@@ -263,7 +263,7 @@ def make_entity_table(schema, tablefmt="github", **kwargs):
Parameters
----------
schema_path : str
- Folder containing schema, which is stored in yaml files.
+ Directory containing schema, which is stored in yaml files.
entities_file : str, optional
File in which entities are described.
This is used for hyperlinks in the table, so the path to the file
diff --git a/tools/schemacode/schemacode/schema.py b/tools/schemacode/schemacode/schema.py
index 1748c3a5aa..54d668d051 100644
--- a/tools/schemacode/schemacode/schema.py
+++ b/tools/schemacode/schemacode/schema.py
@@ -66,7 +66,7 @@ def load_schema(schema_path):
Parameters
----------
schema_path : str
- Folder containing yaml files or yaml file.
+ Directory containing yaml files or yaml file.
Returns
-------
@@ -98,7 +98,7 @@ def load_schema(schema_path):
dict_ = yaml.safe_load(rule_group_file.read_text())
schema["rules"][rule_group_file.stem] = dereference_yaml(dict_, dict_)
- # Load folders of rule subgroups.
+ # Load directories of rule subgroups.
for rule_group_file in sorted(rules_dir.glob("*/*.yaml")):
rule = schema["rules"].setdefault(rule_group_file.parent.name, {})
lgr.debug(f"Loading {rule_group_file.stem} rules.")
diff --git a/tools/schemacode/schemacode/tests/test_schema.py b/tools/schemacode/schemacode/tests/test_schema.py
index 3f71542a81..f058b7e1e2 100644
--- a/tools/schemacode/schemacode/tests/test_schema.py
+++ b/tools/schemacode/schemacode/tests/test_schema.py
@@ -6,7 +6,7 @@
def test_load_schema(schema_dir):
"""Smoke test for schemacode.schema.load_schema."""
- # Pointing to a nonexistent folder should raise a ValueError
+ # Pointing to a nonexistent directory should raise a ValueError
bad_path = "/path/to/nowhere"
with pytest.raises(ValueError):
schema.load_schema(bad_path)
diff --git a/tools/mkdocs_macros_bids/macros.py b/tools/mkdocs_macros_bids/macros.py
index 6f4363fbff..d27aef4f6d 100644
--- a/tools/mkdocs_macros_bids/macros.py
+++ b/tools/mkdocs_macros_bids/macros.py
@@ -113,7 +113,7 @@ def make_metadata_table(field_info):
----------
field_names : dict
A list of the field names.
- Field names correspond to filenames in the "metadata" folder of the
+ Field names correspond to filenames in the "metadata" directory of the
schema.
Until requirement levels can be codified in the schema,
this argument will be dictionary, with the field names as keys and
@@ -138,7 +138,7 @@ def make_columns_table(column_info):
----------
column_info : dict
A list of the column names.
- Column names correspond to filenames in the "columns" folder of the
+ Column names correspond to filenames in the "columns" directory of the
schema.
Until requirement levels can be codified in the schema,
this argument will be a dictionary, with the column names as keys and
@@ -162,7 +162,7 @@ def make_filetree_example(filetree_info, use_pipe=True):
Parameters
----------
filetree_info : dict
Dictionary to represent the folder content.
use_pipe : bool
Set to ``False`` to avoid using pdf unfriendly pipes: "│ └─ ├─"
@@ -162,7 +162,7 @@ def make_filetree_example(filetree_info, use_pipe=True):
filetree_info : dict
- Dictionary to represent the folder content.
+ Dictionary to represent the directory content.
use_pipe : bool
Set to ``False`` to avoid using pdf unfriendly pipes: "│ └─ ├─"
diff --git a/tools/schemacode/schemacode/utils.py b/tools/schemacode/schemacode/utils.py
index 6d2cfcabe5..c2eadc5244 100644
--- a/tools/schemacode/schemacode/utils.py
+++ b/tools/schemacode/schemacode/utils.py
@@ -7,12 +7,12 @@
def get_schema_path():
"""Get the path to the schema folder.
Returns
-------
str
- Absolute path to the folder containing schema-related files.
+ Absolute path to the directory containing schema-related files.
"""
return op.abspath(op.join(op.dirname(__file__), "data", "schema"))
@@ -7,12 +7,12 @@
def get_schema_path():
- """Get the path to the schema folder.
+ """Get the path to the schema directory.
Returns